@@ -1,7 +1,7 @@
 #ifndef LIBXL_C_H
 #define LIBXL_C_H
 
-#define LIBXL_VERSION 0x03070000
+#define LIBXL_VERSION 0x03080000
 
 #ifdef _UNICODE
 
@@ -9,17 +9,25 @@
     #include "SheetW.h"
     #include "FormatW.h"
     #include "FontW.h"
+    #include "AutoFilterW.h"
+    #include "FilterColumnW.h"
 
     #define xlCreateBook xlCreateBookCW
     #define xlCreateXMLBook xlCreateXMLBookCW
     #define xlBookLoad xlBookLoadW
     #define xlBookSave xlBookSaveW
+    #define xlBookLoadUsingTempFile xlBookLoadUsingTempFileW
+    #define xlBookSaveUsingTempFile xlBookSaveUsingTempFileW
+    #define xlBookLoadPartially xlBookLoadPartiallyW
+    #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileW
     #define xlBookLoadRaw xlBookLoadRawW
+    #define xlBookLoadRawPartially xlBookLoadRawPartiallyW
     #define xlBookSaveRaw xlBookSaveRawW
     #define xlBookAddSheet xlBookAddSheetW
     #define xlBookInsertSheet xlBookInsertSheetW
     #define xlBookGetSheet xlBookGetSheetW
     #define xlBookSheetType xlBookSheetTypeW
+    #define xlBookMoveSheet xlBookMoveSheetW
     #define xlBookDelSheet xlBookDelSheetW
     #define xlBookSheetCount xlBookSheetCountW
     #define xlBookAddFormat xlBookAddFormatW
@@ -40,6 +48,7 @@
     #define xlBookGetPicture xlBookGetPictureW
     #define xlBookAddPicture xlBookAddPictureW
     #define xlBookAddPicture2 xlBookAddPicture2W
+    #define xlBookAddPictureAsLink xlBookAddPictureAsLinkW
     #define xlBookDefaultFont xlBookDefaultFontW
     #define xlBookSetDefaultFont xlBookSetDefaultFontW
     #define xlBookSetKey xlBookSetKeyW
@@ -182,6 +191,7 @@
     #define xlSheetSetName xlSheetSetNameW
     #define xlSheetProtect xlSheetProtectW
     #define xlSheetSetProtect xlSheetSetProtectW
+    #define xlSheetSetProtectEx xlSheetSetProtectExW
     #define xlSheetHidden xlSheetHiddenW
     #define xlSheetSetHidden xlSheetSetHiddenW
     #define xlSheetGetTopLeftView xlSheetGetTopLeftViewW
@@ -193,7 +203,12 @@
     #define xlSheetRowColToAddr xlSheetRowColToAddrW
     #define xlSheetSetTabColor xlSheetSetTabColorW
     #define xlSheetSetTabRgbColor xlSheetSetTabRgbColorW
-    #define xlSheetAddIgnoredError addIgnoredErrorW
+    #define xlSheetAddIgnoredError xlSheetAddIgnoredErrorW
+    #define xlSheetAddDataValidation xlSheetAddDataValidationW
+    #define xlSheetAddDataValidationEx xlSheetAddDataValidationExW
+    #define xlSheetAddDataValidationDouble xlSheetAddDataValidationDoubleW
+    #define xlSheetAddDataValidationDoubleEx xlSheetAddDataValidationDoubleExW
+    #define xlSheetRemoveDataValidations removeDataValidationsW
 
     #define xlFontSize xlFontSizeW
     #define xlFontSetSize xlFontSetSizeW
@@ -281,6 +296,7 @@
     #define xlFilterColumnSetTop10 xlFilterColumnSetTop10W
     #define xlFilterColumnGetCustomFilter xlFilterColumnGetCustomFilterW
     #define xlFilterColumnSetCustomFilter xlFilterColumnSetCustomFilterW
+    #define xlFilterColumnSetCustomFilterEx xlFilterColumnSetCustomFilterExW
     #define xlFilterColumnClear xlFilterColumnClearW
 
 #else
@@ -289,17 +305,25 @@
     #include "SheetA.h"
     #include "FormatA.h"
     #include "FontA.h"
+    #include "AutoFilterA.h"
+    #include "FilterColumnA.h"
 
     #define xlCreateBook xlCreateBookCA
     #define xlCreateXMLBook xlCreateXMLBookCA
     #define xlBookLoad xlBookLoadA
     #define xlBookSave xlBookSaveA
+    #define xlBookLoadUsingTempFile xlBookLoadUsingTempFileA
+    #define xlBookSaveUsingTempFile xlBookSaveUsingTempFileA
+    #define xlBookLoadPartially xlBookLoadPartiallyA
+    #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileA
     #define xlBookLoadRaw xlBookLoadRawA
+    #define xlBookLoadRawPartially xlBookLoadRawPartiallyA
     #define xlBookSaveRaw xlBookSaveRawA
     #define xlBookAddSheet xlBookAddSheetA
     #define xlBookInsertSheet xlBookInsertSheetA
     #define xlBookGetSheet xlBookGetSheetA
     #define xlBookSheetType xlBookSheetTypeA
+    #define xlBookMoveSheet xlBookMoveSheetA
     #define xlBookDelSheet xlBookDelSheetA
     #define xlBookSheetCount xlBookSheetCountA
     #define xlBookAddFormat xlBookAddFormatA
@@ -320,6 +344,7 @@
     #define xlBookGetPicture xlBookGetPictureA
     #define xlBookAddPicture xlBookAddPictureA
     #define xlBookAddPicture2 xlBookAddPicture2A
+    #define xlBookAddPictureAsLink xlBookAddPictureAsLinkA
     #define xlBookDefaultFont xlBookDefaultFontA
     #define xlBookSetDefaultFont xlBookSetDefaultFontA
     #define xlBookSetKey xlBookSetKeyA
@@ -462,6 +487,7 @@
     #define xlSheetSetName xlSheetSetNameA
     #define xlSheetProtect xlSheetProtectA
     #define xlSheetSetProtect xlSheetSetProtectA
+    #define xlSheetSetProtectEx xlSheetSetProtectExA
     #define xlSheetHidden xlSheetHiddenA
     #define xlSheetSetHidden xlSheetSetHiddenA
     #define xlSheetGetTopLeftView xlSheetGetTopLeftViewA
@@ -473,7 +499,12 @@
     #define xlSheetRowColToAddr xlSheetRowColToAddrA
     #define xlSheetSetTabColor xlSheetSetTabColorA
     #define xlSheetSetTabRgbColor xlSheetSetTabRgbColorA
-    #define xlSheetAddIgnoredError addIgnoredErrorA
+    #define xlSheetAddIgnoredError xlSheetAddIgnoredErrorA
+    #define xlSheetAddDataValidation xlSheetAddDataValidationA
+    #define xlSheetAddDataValidationEx xlSheetAddDataValidationExA
+    #define xlSheetAddDataValidationDouble xlSheetAddDataValidationDoubleA
+    #define xlSheetAddDataValidationDoubleEx xlSheetAddDataValidationDoubleExA
+    #define xlSheetRemoveDataValidations removeDataValidationsA
 
     #define xlFontSize xlFontSizeA
     #define xlFontSetSize xlFontSetSizeA
@@ -561,6 +592,7 @@
     #define xlFilterColumnSetTop10 xlFilterColumnSetTop10A
     #define xlFilterColumnGetCustomFilter xlFilterColumnGetCustomFilterA
     #define xlFilterColumnSetCustomFilter xlFilterColumnSetCustomFilterA
+    #define xlFilterColumnSetCustomFilterEx xlFilterColumnSetCustomFilterExA
     #define xlFilterColumnClear xlFilterColumnClearA
 
 #endif
